==> clue_0.2-11.tar.gz: clue/man/n_of_classes.Rd <==
\name{n_of_classes}
\alias{n_of_classes}
\alias{cl_class_ids}
\title{Classes in a Partition}
\description{Determine the number of classes and the class ids in a
  partition of objects.}
\usage{
n_of_classes(x)
cl_class_ids(x)
}
\arguments{
  \item{x}{an object representing a (hard or soft) partition.}
}
\value{
  For \code{n_of_classes}, an integer giving the number of classes in
  the partition.
  
  For \code{cl_class_ids}, a vector of integers with the corresponding
  class ids.  For soft partitions, the class ids returned are those of
  the \dQuote{nearest} hard partition obtained by taking the class ids
  of the (first) maximal membership values.
}
\details{
  These function are generic functions.

  The methods provided in package \pkg{clue} handle the partitions
  obtained from clustering functions in the base R distribution, as
  well as packages \pkg{cba}, \pkg{cclust}, \pkg{cluster}, \pkg{e1071},
  \pkg{flexclust}, \pkg{flexmix}, \pkg{kernlab}, and \pkg{mclust} (and
  of course, \pkg{clue} itself).

  Note that the number of classes is taken as the number of distinct
  class ids actually used in the partition, and may differ from the
  number of columns in a membership matrix representing the partition.
}
\seealso{
  \code{\link{is.cl_partition}}
}
\examples{
data("Cassini")
party <- kmeans(Cassini$x, 3)
n_of_classes(party)
## A simple confusion matrix:
table(cl_class_ids(party), Cassini$classes)
## For an "oversize" membership matrix representation:
n_of_classes(cl_membership(party, 6))
}
\keyword{cluster}

==> clue_0.3-0.tar.gz: clue/man/n_of_classes.Rd <==
\name{n_of_classes}
\alias{n_of_classes}
\alias{cl_class_ids}
\title{Classes in a Partition}
\description{Determine the number of classes and the class ids in a
  partition of objects.}
\usage{
n_of_classes(x)
cl_class_ids(x)
}
\arguments{
  \item{x}{an object representing a (hard or soft) partition.}
}
\value{
  For \code{n_of_classes}, an integer giving the number of classes in
  the partition.
  
  For \code{cl_class_ids}, a vector of integers with the corresponding
  class ids.  For soft partitions, the class ids returned are those of
  the \emph{nearest hard partition} obtained by taking the class ids of
  the (first) maximal membership values.
}
\details{
  These function are generic functions.

  The methods provided in package \pkg{clue} handle the partitions
  obtained from clustering functions in the base R distribution, as
  well as packages \pkg{RWeka}, \pkg{cba}, \pkg{cclust}, \pkg{cluster},
  \pkg{e1071}, \pkg{flexclust}, \pkg{flexmix}, \pkg{kernlab}, and
  \pkg{mclust} (and of course, \pkg{clue} itself).

  Note that the number of classes is taken as the number of distinct
  class ids actually used in the partition, and may differ from the
  number of columns in a membership matrix representing the partition.
}
\seealso{
  \code{\link{is.cl_partition}}
}
\examples{
data("Cassini")
party <- kmeans(Cassini$x, 3)
n_of_classes(party)
## A simple confusion matrix:
table(cl_class_ids(party), Cassini$classes)
## For an "oversize" membership matrix representation:
n_of_classes(cl_membership(party, 6))
}
\keyword{cluster}
